@@ -1,6 +1,6 @@
 # pylint: disable=unused-import, redefined-outer-name
 import logging
-from typing import Iterator
+from typing import Generator
 
 import pytest
 from _pytest.logging import caplog  # noqa: F401
@@ -10,8 +10,8 @@ from loguru import logger
 
 @pytest.fixture
 def loguru_caplog(
-    caplog: Iterator[LogCaptureFixture],  # noqa: F811
-) -> Iterator[LogCaptureFixture]:
+    caplog: LogCaptureFixture,  # noqa: F811
+) -> Generator[LogCaptureFixture, None, None]:
     class PropogateHandler(logging.Handler):
         def emit(self, record: logging.LogRecord) -> None:
             logging.getLogger(record.name).handle(record)
